library(shogun)

f_feats_train <- CSVFile("../../data/classifier_binary_2d_nonlinear_features_train.dat")
f_feats_test <- CSVFile("../../data/classifier_binary_2d_nonlinear_features_test.dat")
f_labels_train <- CSVFile("../../data/classifier_binary_2d_nonlinear_labels_train.dat")
f_labels_test <- CSVFile("../../data/classifier_binary_2d_nonlinear_labels_test.dat")

#![create_features]
features_train <- RealFeatures(f_feats_train)
features_test <- RealFeatures(f_feats_test)
labels_train <- BinaryLabels(f_labels_train)
labels_test <- BinaryLabels(f_labels_test)
#![create_features]

#![set_parameters]
C <- 1.0
epsilon <- 0.001
gauss_kernel <- GaussianKernel(features_train, features_train, 15)
#![set_parameters]

#![create_instance]
svm <- LibSVM(C, gauss_kernel, labels_train)
svm$set_epsilon(epsilon)
#![create_instance]

#![train_and_apply]
svm$train()
labels_predict <- svm$apply_binary(features_test)
#![train_and_apply]

#![extract_weights_bias]
alphas <- svm$get_alphas()
b <- svm$get_bias()
#![extract_weights_bias]

#![evaluate_accuracy]
eval <- AccuracyMeasure()
accuracy <- eval$evaluate(labels_predict, labels_test)
#![evaluate_accuracy]

# additional integration testing variables
output <- labels_predict$get_labels()
