library(shogun)

features_p <- GaussianBlobsDataGenerator()
features_q <- GaussianBlobsDataGenerator()

#![create_instance]
mmd <- LinearTimeMMD()
kernel <- GaussianKernel(10, 1)
mmd$set_kernel(kernel)
mmd$set_p(features_p)
mmd$set_q(features_q)
mmd$set_num_samples_p(1000)
mmd$set_num_samples_q(1000)
alpha <- 0.05
#![create_instance]

#![set_burst]
mmd$set_num_blocks_per_burst(1000)
#![set_burst]

#![estimate_mmd]
statistic <- mmd$compute_statistic()
#![estimate_mmd]

#![perform_test]
threshold <- mmd$compute_threshold(alpha)
p_value <- mmd$compute_p_value(statistic)
#![perform_test]

#![add_kernels]
kernel1 <- GaussianKernel(10, 0.1)
kernel2 <- GaussianKernel(10, 1)
kernel3 <- GaussianKernel(10, 10)
mmd$add_kernel(kernel1)
mmd$add_kernel(kernel2)
mmd$add_kernel(kernel3)
#![add_kernels]

#![enable_train_test_mode]
mmd$set_train_test_mode(TRUE)
mmd$set_train_test_ratio(1)
#![enable_train_test_mode]

#![select_kernel_single]
mmd$set_kernel_selection_strategy("KSM_MAXIMIZE_POWER")
mmd$select_kernel()
learnt_kernel_single <- GaussianKernel$obtain_from_generic(mmd$get_kernel())
width <- learnt_kernel_single$get_width()
#![select_kernel_single]

#![select_kernel_combined]
mmd$set_kernel_selection_strategy("KSM_MAXIMIZE_POWER", TRUE)
mmd$select_kernel()
learnt_kernel_combined <- CombinedKernel$obtain_from_generic(mmd$get_kernel())
weights <- learnt_kernel_combined$get_subkernel_weights()
#![select_kernel_combined]

#![perform_test_optimized]
statistic_optimized <- mmd$compute_statistic()
p_value_optimized <- mmd$compute_p_value(statistic)
#![perform_test_optimized]
